=======
Credits
=======

This project was inspired by the pyswarm_ module that performs PSO with constrained support.
The package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _pyswarm: https://github.com/tisimst/pyswarm
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

Development Lead
----------------

* Lester James V. Miranda <ljvmiranda@gmail.com> 

Contributors
------------

* `@Carl-K`_


.. _`@Carl-K`: https://github.com/Carl-K
